@@ -27,8 +27,11 @@ class Compass : public QWidget {
 
  public slots:
   void setPosition(const QGeoPositionInfo &);
+  void setTarget(const QGeoCoordinate &);
   void setPosition(const QCompassReading *);
   void timerExpired();
+  void setType();
+  void setType(const Waypoint &);
 
  private:
   bool load(QSvgRenderer *, const QString &);
@@ -44,6 +47,7 @@ class Compass : public QWidget {
   static const qreal RATE=10;
   QPixmap *m_bgPix, *m_calPix;
   Cache m_cache;
+  QGeoCoordinate m_target, m_lastPos;
 };
 
 #endif // COMPASS_H
