@@ -12,6 +12,9 @@ class DescriptionWindow : public CustomWindow {
   DescriptionWindow(const Cache &, QWidget * = 0);
   ~DescriptionWindow();
 
+ private slots:
+  void openCacheUrl();
+
  private:
   Cache m_cache;
 };
