@@ -11,6 +11,8 @@
 
 #include "cache.h"
 #include "iconloader.h"
+#include "locationprovider.h"
+#include "waypointdb.h"
 
 #include "mapoverlay.h"
 #include "mapbanner.h"
@@ -30,6 +32,9 @@ class MapWidget : public QGraphicsGeoMap {
   void hideBubble();
   QString managerName();
   void paint(QPainter *, const QStyleOptionGraphicsItem *, QWidget * = 0);
+  bool hiRez() const;
+  void setHiRez(bool);
+  void setWaypointDb(WaypointDb *);
 
  signals:
   void mapChanged();
@@ -49,11 +54,13 @@ class MapWidget : public QGraphicsGeoMap {
   void addBanner(const QString &);
   
  private slots:
+  void reloadCustomWaypoints();
   void reloadTimerExpired();
   void reload();
   void zoomLevelChangedEvent(qreal);
   void centerChangedEvent(const QGeoCoordinate &);
   void positionUpdated(const QGeoPositionInfo &);
+  void positionUpdated(const QCompassReading *);
   
  protected:
   void mousePressEvent(QGraphicsSceneMouseEvent *);
@@ -91,9 +98,11 @@ class MapWidget : public QGraphicsGeoMap {
   bool m_dragging;
   bool m_posIsValid;
   bool m_gpsLocked;
+  bool m_hiRez;
   int m_precisionAlpha;
   QString m_selectedCache;
   QList<Waypoint> m_selectedWaypoints;
+  qreal m_compass;
 
   // make sure map is only updated if it's dragged
   // significantly
@@ -103,6 +112,9 @@ class MapWidget : public QGraphicsGeoMap {
   QGeoMapCircleObject *m_gpsPrecision;
   QGeoMapGroupObject *m_cacheGroup;
   QGeoMappingManager *m_manager;
+
+  WaypointDb *m_wptDb;
+  QList<Waypoint> m_customWpts;
 };
 
 #endif // MAP_WIDGET_H
