@@ -37,8 +37,10 @@ private:
 };
 
 NavigationWindow::NavigationWindow(const Cache &cache, 
-	   LocationProvider *locationProvider, QWidget *parent) : 
-  CustomWindow("NavigationWindow", parent), m_cache(cache) {
+	   LocationProvider *locationProvider, 
+	   WaypointDb *wptDb, QWidget *parent) : 
+  CustomWindow("NavigationWindow", parent), m_cache(cache),
+  m_coordinateTool(NULL), m_coo(cache.coordinate()) {
 
   setWindowTitle(tr("Navigation"));
 
@@ -54,16 +56,8 @@ NavigationWindow::NavigationWindow(const Cache &cache,
   layout->setContentsMargins(0,0,0,0);
   layout->setSpacing(0);
 
-  QGroupBox *groupBox = new QGroupBox(tr("Distance"));
+  QGroupBox *groupBox = new QGroupBox();
   QVBoxLayout *ivbox = new QVBoxLayout;
-  m_distance = new QLabel("");
-  ivbox->addWidget(m_distance, 0, Qt::AlignHCenter);
-  groupBox->setLayout(ivbox);
-  layout->addWidget(groupBox);
-  layout->addStretch();
-
-  groupBox = new QGroupBox(tr("Current coordinate"));
-  ivbox = new QVBoxLayout;
   m_latitude = new InfoWidget(tr("Latitude"));
   ivbox->addWidget(m_latitude);
   m_longitude = new InfoWidget(tr("Longitude"));
@@ -72,14 +66,12 @@ NavigationWindow::NavigationWindow(const Cache &cache,
   layout->addWidget(groupBox);
   layout->addStretch();
 
-  groupBox = new QGroupBox(tr("Cache coordinate"));
-  ivbox = new QVBoxLayout;
-  ivbox->addWidget(new InfoWidget(tr("Latitude"), 
-		 latitudeString(m_cache.coordinate())));
-  ivbox->addWidget(new InfoWidget(tr("Longitude"),
-  	         longitudeString(m_cache.coordinate())));
-  groupBox->setLayout(ivbox);
-  layout->addWidget(groupBox);
+  m_coordinateTool = new CoordinateTool(m_cache, wptDb, this);
+  layout->addWidget(m_coordinateTool->createWidget());
+
+  m_distance = new InfoWidget(tr("Distance"));
+  m_coordinateTool->addWidget(m_distance);
+
   layout->addStretch();
 
 
@@ -88,6 +80,15 @@ NavigationWindow::NavigationWindow(const Cache &cache,
 
   setCentralWidget(sbox);
 
+  connect(m_coordinateTool, SIGNAL(coordinateChanged(const QGeoCoordinate &)),
+	  compass, SLOT(setTarget(const QGeoCoordinate &)));
+  connect(m_coordinateTool, SIGNAL(typeChanged(const Waypoint &)),
+	  compass, SLOT(setType(const Waypoint &)));
+  connect(m_coordinateTool, SIGNAL(typeChanged()),
+	  compass, SLOT(setType()));
+  connect(m_coordinateTool, SIGNAL(coordinateChanged(const QGeoCoordinate &)),
+	  this, SLOT(setTarget(const QGeoCoordinate &)));
+
   // send position/azimuth updates to compass widget
   connect(locationProvider, SIGNAL(positionUpdated(const QGeoPositionInfo &)), 
 	  compass, SLOT(setPosition(const QGeoPositionInfo &)));
@@ -101,52 +102,20 @@ NavigationWindow::NavigationWindow(const Cache &cache,
 
 NavigationWindow::~NavigationWindow() {
   qDebug() << __FUNCTION__;
+
+  if(m_coordinateTool) delete m_coordinateTool;
+}
+
+void NavigationWindow::setTarget(const QGeoCoordinate &coo) {
+  m_coo = coo;
 }
 
 void NavigationWindow::setPosition(const QGeoPositionInfo &pos) {
-  qreal dist = pos.coordinate().distanceTo(m_cache.coordinate());
+  qreal dist = pos.coordinate().distanceTo(m_coo);
 
-  m_distance->setText("<b>" + distanceString(dist) + "</b>");
-  m_latitude->setInfo(latitudeString(pos.coordinate()));
-  m_longitude->setInfo(longitudeString(pos.coordinate()));
-}
-
-QString NavigationWindow::zeroCut(qreal num, int p, int c) {
-  return QString("000").append(QString::number(num, 'f', p)).right(c+p);
-}
-
-QString NavigationWindow::latitudeString(const QGeoCoordinate &coo) {
-  QString str;
-
-  if(coo.isValid()) {
-    qreal fractional, latitude = coo.latitude();
-    double integral;
-
-    if(latitude < 0) { latitude = fabs(latitude); str = tr("S");
-    } else                                        str = tr("N");
-
-    fractional = modf(latitude, &integral);
-    str += " " + zeroCut(integral, 0, 2) + "\260 " +
-      zeroCut(60*fractional, 3, 3) + "'";
-  }
-  return str;
-}
-
-QString NavigationWindow::longitudeString(const QGeoCoordinate &coo) {
-  QString str;
-
-  if(coo.isValid()) {
-    qreal fractional, longitude = coo.longitude();
-    double integral;
-
-    if(longitude < 0) { longitude = fabs(longitude); str = tr("W");
-    } else                                           str = tr("E");
-
-    fractional = modf(longitude, &integral);
-    str += " " + zeroCut(integral, 0, 3) + "\260 " +
-      zeroCut(60*fractional, 3, 3) + "'";
-  }
-  return str;
+  m_distance->setInfo(distanceString(dist));
+  m_latitude->setInfo(CoordinateTool::latitudeString(pos.coordinate()));
+  m_longitude->setInfo(CoordinateTool::longitudeString(pos.coordinate()));
 }
 
 QString NavigationWindow::distanceString(qreal dist) {
